@@ -1,4 +1,4 @@
-# Copyright 2021 VMware, Inc.
+# Copyright 2021-2023 VMware, Inc.
 # SPDX-License-Identifier: Apache-2.0
 import _io
 import json
@@ -11,13 +11,13 @@ from typing import Tuple
 from typing import Type
 
 import click
-from tabulate import tabulate
 from vdk.internal.control.configuration.defaults_config import load_default_team_name
 from vdk.internal.control.exception.vdk_exception import VDKException
 from vdk.internal.control.rest_lib.factory import ApiClientFactory
 from vdk.internal.control.rest_lib.rest_client_errors import ApiClientErrorDecorator
 from vdk.internal.control.utils import cli_utils
-from vdk.internal.control.utils.cli_utils import OutputFormat
+from vdk.internal.control.utils import output_printer
+from vdk.internal.control.utils.output_printer import OutputFormat
 
 log = logging.getLogger(__name__)
 
@@ -29,7 +29,6 @@ class PropertyOperation(Enum):
     """
 
     SET = "set"
-    SET_SECRET = "set_secret"  # nosec
     GET = "get"
 
 
@@ -39,40 +38,30 @@ class JobProperties:
         rest_api_url: str,
         job_name: str,
         team: str,
-        output: OutputFormat,
+        output_format: OutputFormat,
     ):
-        self.properties_api = ApiClientFactory(rest_api_url).get_properties_api()
-        self.output = output
-        self.job_name = job_name
-        self.team = team
-        self.deployment_id = "TODO"
+        self.__properties_api = ApiClientFactory(rest_api_url).get_properties_api()
+        self.__output = output_format
+        self.__printer = output_printer.create_printer(output_format)
+        self.__job_name = job_name
+        self.__team = team
+        self.__deployment_id = "TODO"
 
     def __get_all_remote_properties(self) -> Dict[str, Any]:
-        return self.properties_api.data_job_properties_read(
-            team_name=self.team,
-            job_name=self.job_name,
-            deployment_id=self.deployment_id,
+        return self.__properties_api.data_job_properties_read(
+            team_name=self.__team,
+            job_name=self.__job_name,
+            deployment_id=self.__deployment_id,
         )
 
     def __list_properties(self, remote_props: Dict[str, Any]) -> None:
-        if self.output == OutputFormat.TEXT.value:
-            if len(remote_props) > 0:
-                click.echo(
-                    tabulate(
-                        [[k, v] for k, v in remote_props.items()],
-                        headers=("key", "value"),
-                    )
-                )
-            else:
-                click.echo("No properties.")
-        else:
-            click.echo(json.dumps(remote_props))
+        self.__printer.print_dict(remote_props)
 
     @staticmethod
     def _to_bool(value: str) -> bool:
-        if value == "true" or value == "True":
+        if value.lower() == "true":
             return True
-        if value == "false" or value == "False":
+        if value.lower() == "false":
             return False
         raise ValueError("bool cast accept only True/true/False/false values.")
 
@@ -138,19 +127,19 @@ class JobProperties:
     def update_properties(self, new_properties: Dict[str, str]) -> None:
         remote_props = self.__get_all_remote_properties()
         merged_props = self.__merge_props(new_properties, remote_props)
-        self.properties_api.data_job_properties_update(
-            team_name=self.team,
-            job_name=self.job_name,
-            deployment_id=self.deployment_id,
+        self.__properties_api.data_job_properties_update(
+            team_name=self.__team,
+            job_name=self.__job_name,
+            deployment_id=self.__deployment_id,
             request_body=merged_props,
         )
 
     @ApiClientErrorDecorator()
     def overwrite_properties(self, new_properties: Dict[str, str]) -> None:
-        self.properties_api.data_job_properties_update(
-            team_name=self.team,
-            job_name=self.job_name,
-            deployment_id=self.deployment_id,
+        self.__properties_api.data_job_properties_update(
+            team_name=self.__team,
+            job_name=self.__job_name,
+            deployment_id=self.__deployment_id,
             request_body=new_properties,
         )
 
@@ -159,19 +148,19 @@ class JobProperties:
         props = self.__get_all_remote_properties()
         for key in delete_keys:
             props.pop(key)
-        self.properties_api.data_job_properties_update(
-            team_name=self.team,
-            job_name=self.job_name,
-            deployment_id=self.deployment_id,
+        self.__properties_api.data_job_properties_update(
+            team_name=self.__team,
+            job_name=self.__job_name,
+            deployment_id=self.__deployment_id,
             request_body=props,
         )
 
     @ApiClientErrorDecorator()
     def delete_all_job_properties(self) -> None:
-        self.properties_api.data_job_properties_update(
-            team_name=self.team,
-            job_name=self.job_name,
-            deployment_id=self.deployment_id,
+        self.__properties_api.data_job_properties_update(
+            team_name=self.__team,
+            job_name=self.__job_name,
+            deployment_id=self.__deployment_id,
             request_body={},
         )
 
@@ -186,8 +175,8 @@ class JobProperties:
     """
          Job properties are most commonly used to:
 
-         * store credentials securely
          * store data job state
+         * store credentials (when a secrets backend has not been configured)
 
      Examples:
 
@@ -195,13 +184,9 @@ class JobProperties:
      # Set single property with key "my-key" and value "my-value".
      vdk properties --set my-key "my-value"
 
-     \b
-     # Will prompt for the value so it's not printed on the screen.
-     vdk properties --set-secret "my-secret"
-
      \b
      # Update multiple properties at once.
-     vdk properties --set "key1" "value1" --set "key2" "value2" --set-secret "secret1" --set-secret "secret2"
+     vdk properties --set "key1" "value1" --set "key2" "value2"
 
      \b
      # Use backslash \\ to set them on multiple lines
@@ -245,13 +230,6 @@ class JobProperties:
     "Entirely new properties will be set with string type"
     "You can set multiple properties by using --set multiple times",
 )
-@click.option(
-    "--set-secret",
-    multiple=True,
-    type=click.STRING,
-    help="Set key value property which is a secret. It behaves almost the same way as --set."
-    "The difference from --set is that it will be prompted and input would be masked. ",
-)
 @click.option(
     "--delete",
     nargs=1,
@@ -283,7 +261,6 @@ def properties_command(
     name: str,
     team: str,
     set: Tuple[str, str],
-    set_secret: Tuple[str, str],
     delete: Tuple[str],
     delete_all_job_properties: bool,
     overwrite_all_job_properties: _io.BufferedReader,
@@ -292,12 +269,12 @@ def properties_command(
     rest_api_url: str,
     output: OutputFormat,
 ):
-    if (set or set_secret or delete) and (get or list):
+    if (set or delete) and (get or list):
         raise VDKException(
             what="Invalid arguments",
-            why="Wrong input. Cannot pass --get or --list at the same time as --set or --set-secret.",
+            why="Wrong input. Cannot pass --get or --list at the same time as --set.",
             consequence="Command will abort with error.",
-            countermeasure="Fix passed arguments such that get/list are not passed in the same time as set/set-secret.",
+            countermeasure="Fix passed arguments such that get/list are not passed in the same time as set/.",
         )
     if get and list:
         raise VDKException(
@@ -308,10 +285,10 @@ def properties_command(
         )
     log.debug(
         f"properties passed options: name: {name}, team: {team}, "
-        f"set: {set}, set_secret: {set_secret}, get: {get}, list: {list}, delete: {delete} "
+        f"set: {set}, get: {get}, list: {list}, delete: {delete} "
         f"rest_api_url: {rest_api_url}, output: {output}"
     )
-    key_value_pairs = _get_key_value_pairs(set, set_secret)
+    key_value_pairs = _get_key_value_pairs(set)
     cmd = JobProperties(rest_api_url, name, team, output)
     if key_value_pairs:
         cmd.update_properties(key_value_pairs)
@@ -337,13 +314,9 @@ def properties_command(
             )
 
 
-def _get_key_value_pairs(set, set_secret):
+def _get_key_value_pairs(set):
     key_value_pairs = {}
     if set:
         for key, value in set:
             key_value_pairs[key] = value
-    if set_secret:
-        for key in set_secret:
-            value = click.prompt(f"{key}", hide_input=True)
-            key_value_pairs[key] = value
     return key_value_pairs
